package com.muyu.common.nacos.remote.interceptor;

import com.dtflys.forest.http.ForestRequest;
import com.dtflys.forest.interceptor.Interceptor;
import com.muyu.common.core.text.Convert;
import com.muyu.common.core.utils.StringUtils;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Value;

@Log4j2
public class NacosNamespaceInterceptor<T> implements Interceptor<T> {
    @Value("${nacos.namespace}")
    private String namespaceId;

    @Override
    public boolean beforeExecute(ForestRequest req){
        if(StringUtils.isNotEmpty(namespaceId)){
            String reqNamespaceId = Convert.utf8Str(req.getQuery("namespaceId"));
            if(reqNamespaceId == null){
                log.warn("本次请求nacos的namespaceId未携带，已添加[{}]",namespaceId);
                req.addQuery("namespaceId",namespaceId);
            }else {
                if(StringUtils.equals(reqNamespaceId,namespaceId)){
                    log.warn("本次请求nacos的namespaceId和项目ID不相符，现已更改：[{}->{}]",reqNamespaceId,namespaceId);
                    req.addQuery("namespaceId",namespaceId);
                }
            }
        }
        return true;
    }
}
